Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(86)

Unified Diff: runtime/bin/extensions.cc

Issue 2694103004: Cleanup app snapshots on isolate/vm exit. (Closed)
Patch Set: merge Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/extensions.h ('k') | runtime/bin/extensions_android.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/extensions.cc
diff --git a/runtime/bin/extensions.cc b/runtime/bin/extensions.cc
index fd0961f205b9097be849f42778f02fa5f799424e..93dc2c24178bae3d6e78ee7d6bcccfbc6d7d975e 100644
--- a/runtime/bin/extensions.cc
+++ b/runtime/bin/extensions.cc
@@ -38,7 +38,7 @@ void* Extensions::MakePathAndResolve(const char* dir, const char* name) {
NULL,
};
const char* library_file = Concatenate(path_components);
- void* library_handle = LoadExtensionLibrary(library_file);
+ void* library_handle = LoadLibrary(library_file);
if (library_handle != NULL) {
return library_handle;
}
@@ -55,13 +55,13 @@ void* Extensions::MakePathAndResolve(const char* dir, const char* name) {
NULL,
};
const char* library_file = Concatenate(path_components);
- return LoadExtensionLibrary(library_file);
+ return LoadLibrary(library_file);
}
}
// IMPORTANT: In the absolute path case, do not extract the filename and search
// for that by passing it to LoadExtensionLibrary. That can lead to confusion in
// which the absolute path is wrong, and a different version of the library is
// loaded from the standard location.
void* Extensions::ResolveAbsPathExtension(const char* extension_path) {
@@ -55,13 +55,13 @@ void* Extensions::MakePathAndResolve(const char* dir, const char* name) {
}
// IMPORTANT: In the absolute path case, do not extract the filename and search
-// for that by passing it to LoadExtensionLibrary. That can lead to confusion in
+// for that by passing it to LoadLibrary. That can lead to confusion in
// which the absolute path is wrong, and a different version of the library is
// loaded from the standard location.
« no previous file with comments | « runtime/bin/extensions.h ('k') | runtime/bin/extensions_android.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698